@@ -271,23 +271,29 @@ def create_company_years_column(df):
 
     CurrentYear = date.today().year
     df['YearFounded'] = df['YearFounded'].fillna(0)
-    df.loc[(CurrentYear - df['YearFounded'] <= 2),
-           'CompanyYears'] = "0-2 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 2) & (
-        CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "0-2 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 2) & (
-        CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "3-5 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 5) & (
-        CurrentYear - df['YearFounded'] <= 10), 'CompanyYears'] = "6-10 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 10) & (
-        CurrentYear - df['YearFounded'] <= 25), 'CompanyYears'] = "11-25 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 25) & (
-        CurrentYear - df['YearFounded'] <= 50), 'CompanyYears'] = "26-50 Years"
-    df.loc[(CurrentYear - df['YearFounded'] > 50),
-           'CompanyYears'] = "51+ Years"
-    # Errors go to "unknown category"
-    df.loc[(df['YearFounded'] > CurrentYear) | (
-        df['YearFounded'] < 1600), 'CompanyYears'] = "Unknown"
+    df['CompanyYears']= CurrentYear-df['YearFounded']
+    df.loc[(df['CompanyYears'] < 0) | (df['CompanyYears'] > 150),'CompanyYears'] = np.nan
+
+
+    # df.loc[(CurrentYear - df['YearFounded'] <= 2),
+    #        'CompanyYears'] = "0-2 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 2) & (
+    #     CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "0-2 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 2) & (
+    #     CurrentYear - df['YearFounded'] <= 5), 'CompanyYears'] = "3-5 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 5) & (
+    #     CurrentYear - df['YearFounded'] <= 10), 'CompanyYears'] = "6-10 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 10) & (
+    #     CurrentYear - df['YearFounded'] <= 25), 'CompanyYears'] = "11-25 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 25) & (
+    #     CurrentYear - df['YearFounded'] <= 50), 'CompanyYears'] = "26-50 Years"
+    # df.loc[(CurrentYear - df['YearFounded'] > 50),
+    #        'CompanyYears'] = "51+ Years"
+    # # Errors go to "unknown category"
+    # df.loc[(df['YearFounded'] > CurrentYear) | (
+    #     df['YearFounded'] < 1600), 'CompanyYears'] = "Unknown"
+
+    
     df = df.drop(['YearFounded'], axis=1)
     return df
 
